@@ -14,7 +14,7 @@ using DocStringExtensions: DocStringExtensions, TYPEDEF, TYPEDFIELDS
 include("settypes/recursiveset.jl")
 include("settypes/sortedvector.jl")
 
-include("patterns.jl")
+include("set_operations.jl")
 include("tracers.jl")
 include("exceptions.jl")
 include("operators.jl")
@@ -26,7 +26,7 @@ include("overloads/utils.jl")
 include("overloads/special_cases.jl")
 include("overloads/three_arg.jl")
 include("overloads/ifelse_global.jl")
-include("overloads/dual.jl")
+include("overloads/is_functions.jl")
 include("overloads/arrays.jl")
 include("overloads/ambiguities.jl")
 
@@ -36,6 +36,7 @@ include("adtypes_interface.jl")
 
 export TracerSparsityDetector
 export TracerLocalSparsityDetector
+
 # Reexport ADTypes interface
 export jacobian_sparsity, hessian_sparsity
 
